summaryrefslogtreecommitdiffstats
path: root/wineconfig/wineconfig.py
diff options
context:
space:
mode:
Diffstat (limited to 'wineconfig/wineconfig.py')
-rwxr-xr-xwineconfig/wineconfig.py10
1 files changed, 5 insertions, 5 deletions
diff --git a/wineconfig/wineconfig.py b/wineconfig/wineconfig.py
index d4c39ac..f662915 100755
--- a/wineconfig/wineconfig.py
+++ b/wineconfig/wineconfig.py
@@ -17,8 +17,8 @@
###########################################################################
from qt import *
-from kdecore import *
-from kdeui import *
+from tdecore import *
+from tdeui import *
from kfile import *
from kio import *
#import string
@@ -284,14 +284,14 @@ class WineConfigApp(programbase):
def InstallWine(self):
""" Allows the user to enable the proper repositories and
install wine.
Currently Kubuntu specific, requires kdesudo, adept_batch
and software-properties-kde """
if not isroot:
- if os.system("kdesudo \"software-properties-kde --enable-component universe\""):
+ if os.system("tdesudo \"software-properties-kde --enable-component universe\""):
KMessageBox.error(self, i18n("There was a problem running " + \
"software-properties-kde. Make sure " + \
"software-properties-kde is installed."))
- elif os.system("kdesudo \"adept_batch install wine\""):
+ elif os.system("tdesudo \"adept_batch install wine\""):
KMessageBox.error(self, i18n("There was a problem running " + \
"adept_batch. Make sure " + \
"Adept is installed."))
@@ -284,14 +284,14 @@ class WineConfigApp(programbase):
""" Allows the user to enable the proper repositories and
install wine.
- Currently Kubuntu specific, requires kdesudo, adept_batch
+ Currently Kubuntu specific, requires tdesudo, adept_batch
and software-properties-kde """
if not isroot: